/*
 * This file is part of the ESO UVES Pipeline
 * Copyright (C) 2004,2005 European Southern Observatory
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, 51 Franklin St, Fifth Floor, Boston, MA  02111-1307  USA
 */
/*
 * $Author: jtaylor $
 * $Date: 2012/11/19 09:16:16 $
 * $Revision: 1.4 $
 * $Name: HEAD $
 * $Log: flames_standard.h,v $
 * Revision 1.4  2012/11/19 09:16:16  jtaylor
 * replace all (u)long ints with (u)int32_t in flames
 *
 * except the fitsio arguments in load_frame() from uves/flames_midas_def.c
 * the rest of uves is unchanged
 * (uves/uves_deque.c must not be changed for compatibility with cpl)
 *
 * required for 64 bit compatibility
 * the midas fits io does not support 8 byte long integers.
 * longs are 4 byte on 32 bit and 8 byte on 64 bit so the simplest fix is
 * to replace them all with the size which is known to work.
 * An alternative would be to check and fix all io related functions
 * this would require adding a 4 byte integer tensor
 *
 * Revision 1.3  2010/09/24 09:31:30  amodigli
 * put back QFITS dependency to fix problem spot by NRI on FIBER mode (with MIDAS calibs) data
 *
 * Revision 1.1  2007/07/27 06:44:09  amodigli
 * added to repository
 *
 */

#ifndef FLAMES_STANDARD_H
#define FLAMES_STANDARD_H

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <flames_uves.h>

/* This function makes the standard extraction */

flames_err 
standard(flames_frame *ScienceFrame, 
         allflats *SingleFF, 
         orderpos *Order, 
     int32_t ordsta, 
         int32_t ordend, 
         frame_mask **mask,  
     double ***pfibrecentre, 
         double phalfwinsize);

#endif
